<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>CommonDialogs</name>
    <message>
        <location filename="../CommonDialogs.h" line="11"/>
        <source>Question...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="12"/>
        <source>Warning...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="13"/>
        <source>Information...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="14"/>
        <source>Get Item...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="15"/>
        <source>Get Save File Name...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="16"/>
        <source>Get Open File Name...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="17"/>
        <source>Get Existing Directory...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIAbout</name>
    <message>
        <location filename="../ui/UIAbout.ui" line="13"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="19"/>
        <source>Yabause Qt Gui&lt;br /&gt;Based on Yabause %1&lt;br /&gt;&lt;a href=&quot;http://yabause.org&quot;&gt;http://yabause.org&lt;/a&gt;&lt;br /&gt;The Yabause Team&lt;br /&gt;&lt;a href=&quot;mailto:pasnox@gmail.com&quot;&gt;Filipe AZEVEDO&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="38"/>
        <source>http://www.monkeystudio.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="41"/>
        <source>&lt;a href=&quot;http://www.monkeystudio.org&quot;&gt;&lt;img src=&quot;:/icons/icons/made.png&quot;&gt;&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="75"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIBackupRam</name>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="13"/>
        <source>Backup Ram Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="19"/>
        <source>Device List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="37"/>
        <source>Save List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="51"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="58"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="70"/>
        <source>Save Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="76"/>
        <source>File Name :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="90"/>
        <source>Comment :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="104"/>
        <source>Language :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="118"/>
        <source>Data Size :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="132"/>
        <source>Block Size :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="49"/>
        <source>%1/%2 blocks free</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="76"/>
        <source>Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="79"/>
        <source>English</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="82"/>
        <source>French</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="85"/>
        <source>German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="88"/>
        <source>Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="91"/>
        <source>Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="94"/>
        <source>Unknow (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="116"/>
        <source>Are you sure you want to delete &apos;%1&apos; ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="127"/>
        <source>Are you sure you want to format &apos;%1&apos; ?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UICheatAR</name>
    <message>
        <location filename="../ui/UICheatAR.ui" line="13"/>
        <source>Add Action Replay Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="19"/>
        <source>Action Replay Code :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="33"/>
        <source>Description :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="60"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;WARNING:&lt;/b&gt; Master Codes are &lt;b&gt;NOT&lt;/b&gt; supported.&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UICheatRaw</name>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="13"/>
        <source>Add Raw Memory Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="19"/>
        <source>Cheat Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="25"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="32"/>
        <source>Byte Write</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="39"/>
        <source>Word Write</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="46"/>
        <source>Long Write</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="56"/>
        <source>Address :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="70"/>
        <source>Value :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="84"/>
        <source>Description :</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UICheats</name>
    <message>
        <location filename="../ui/UICheats.ui" line="13"/>
        <source>Cheats</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="23"/>
        <source>Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="28"/>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="33"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="46"/>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="69"/>
        <source>&amp;Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="78"/>
        <source>Add Codes...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="84"/>
        <source>&amp;Action Replay</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="104"/>
        <source>&amp;Raw Memory Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="114"/>
        <source>Cheats File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="123"/>
        <source>&amp;Save To File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="143"/>
        <source>&amp;Load From File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="127"/>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="127"/>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="95"/>
        <source>Unable to add code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="103"/>
        <source>Unable to change description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="82"/>
        <source>Invalid Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="89"/>
        <source>Invalid Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="142"/>
        <source>Unable to remove code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="181"/>
        <source>Choose a cheat file to save to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="189"/>
        <source>Yabause Cheat Files (*.yct);;All Files (*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="184"/>
        <source>Unable to open file for loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="189"/>
        <source>Choose a cheat file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="204"/>
        <source>Unable to open file for saving</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UISettings</name>
    <message>
        <location filename="../ui/UISettings.ui" line="13"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="23"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="35"/>
        <source>Bios</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="344"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="61"/>
        <source>Cd-Rom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="90"/>
        <source>Save States</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="124"/>
        <source>Video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="136"/>
        <source>Video Core</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="155"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="165"/>
        <source>Width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="175"/>
        <source>Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="182"/>
        <source>Height</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="198"/>
        <source>Video Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="225"/>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="237"/>
        <source>Sound Core</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="264"/>
        <source>Cart/Memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="276"/>
        <source>Cartridge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="305"/>
        <source>Memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="331"/>
        <source>Mpeg ROM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="377"/>
        <source>Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="413"/>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="764"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="442"/>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="471"/>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="500"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="529"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="558"/>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="587"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="616"/>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="638"/>
        <source>L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="645"/>
        <source>Left trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="674"/>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="696"/>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="703"/>
        <source>Right trigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="732"/>
        <source>Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="761"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="807"/>
        <source>Advanced</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="819"/>
        <source>Region</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="838"/>
        <source>SH2 Interpreter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="127"/>
        <source>CD Rom Drive...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="138"/>
        <source>Choose a bios file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="143"/>
        <source>The dummies cores don&apos;t need configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="151"/>
        <source>Choose a cdrom drive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="153"/>
        <source>Choose a cdrom mount point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="158"/>
        <source>Choose a folder to store save states</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="160"/>
        <source>Choose a cartridge file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="162"/>
        <source>Choose a memory file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="164"/>
        <source>Choose a mpeg rom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIWaitInput</name>
    <message>
        <location filename="../ui/UIWaitInput.ui" line="19"/>
        <source>Waiting Input...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UIYabause</name>
    <message>
        <location filename="../ui/UIYabause.ui" line="13"/>
        <source>Yabause Qt GUI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="56"/>
        <source>Volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="78"/>
        <source>Mute/UnMute Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="129"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="133"/>
        <source>Save State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="153"/>
        <source>Load State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="185"/>
        <source>&amp;View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="189"/>
        <source>&amp;Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="211"/>
        <source>&amp;Debug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="225"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="232"/>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="240"/>
        <source>Emulation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="257"/>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="291"/>
        <source>&amp;Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="294"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="299"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="304"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="312"/>
        <source>&amp;Settings...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="315"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="323"/>
        <source>R&amp;un</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="340"/>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="337"/>
        <source>&amp;Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="351"/>
        <source>&amp;Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="354"/>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="365"/>
        <source>Transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="368"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="376"/>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="379"/>
        <source>Ctrl+Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="390"/>
        <source>Frame Skip/Limiter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="393"/>
        <source>ScrollLock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="404"/>
        <source>FPS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="455"/>
        <source>Vdp1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="426"/>
        <source>&amp;Fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="429"/>
        <source>Alt+Return</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="440"/>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="445"/>
        <source>MSH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="450"/>
        <source>SSH2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="460"/>
        <source>Vdp2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="465"/>
        <source>M68K</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="470"/>
        <source>SCU-DSP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="475"/>
        <source>SCSP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="480"/>
        <source>Memory Dump</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="488"/>
        <source>&amp;About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="499"/>
        <source>NBG0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="510"/>
        <source>NBG1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="521"/>
        <source>NBG2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="532"/>
        <source>NBG3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="543"/>
        <source>RBG0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="620"/>
        <source>1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="551"/>
        <source>Ctrl+1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="628"/>
        <source>2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="559"/>
        <source>Ctrl+2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="636"/>
        <source>3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="567"/>
        <source>Ctrl+3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="644"/>
        <source>4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="575"/>
        <source>Ctrl+4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="652"/>
        <source>5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="583"/>
        <source>Ctrl+5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="660"/>
        <source>6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="591"/>
        <source>Ctrl+6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="668"/>
        <source>7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="599"/>
        <source>Ctrl+7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="676"/>
        <source>8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="607"/>
        <source>Ctrl+8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="684"/>
        <source>9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="615"/>
        <source>Ctrl+9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="623"/>
        <source>Alt+1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="631"/>
        <source>Alt+2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="639"/>
        <source>Alt+3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="647"/>
        <source>Alt+4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="655"/>
        <source>Alt+5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="663"/>
        <source>Alt+6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="671"/>
        <source>Alt+7</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="679"/>
        <source>Alt+8</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="687"/>
        <source>Alt+9</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="692"/>
        <source>To File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="695"/>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="700"/>
        <source>From File...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="703"/>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="711"/>
        <source>Cheats List...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="714"/>
        <source>Ctrl+L</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="722"/>
        <source>Backup Manager...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="725"/>
        <source>Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="733"/>
        <source>Open ISO...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="736"/>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="744"/>
        <source>Open CD Rom...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="747"/>
        <source>Ctrl+C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="755"/>
        <source>Emu-Compatibility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="758"/>
        <source>http://www.emu-compatibility.com/yabause/index.php?lang=uk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="766"/>
        <source>Sound...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="774"/>
        <source>Video Driver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="787"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="782"/>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="790"/>
        <source>Alt+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="238"/>
        <source>Yabause is not initialized, can&apos;t open ISO.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="241"/>
        <source>Select your iso/cue/bin file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="241"/>
        <source>Yabause Save State (*.iso *.cue *.bin)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="260"/>
        <source>Yabause is not initialized, can&apos;t open CD Rom.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="263"/>
        <source>Select a cdrom volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="310"/>
        <source>Couldn&apos;t save state file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="320"/>
        <source>Couldn&apos;t load state file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="306"/>
        <source>Choose a file to save your state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="316"/>
        <source>Yabause Save State (*.yss )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="316"/>
        <source>Select a file to load your state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="334"/>
        <source>%1 Images (*.%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="340"/>
        <source>Choose a location for your screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="345"/>
        <source>An error occur while writing the screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="391"/>
        <source>Yabause is not initialized, can&apos;t manage backup ram.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
